amachine.am_substitution_algebra API documentation

# amachine.am_substitution_algebra

View Source

     1from dataclasses import dataclass
     2
     3from .am_machine import Machine
     4from .am_syntagmatics import Syntagmatics
     5
     6@dataclass
     7class SubstitutionAlgebra:
     8    """
     9    The algebraic structure of valid substitutions over a Machine,
    10    derived from a syntagmatic specification, and the machines internal constraints.
    11    """
    12    syntagmatics : Syntagmatics
    13    model        : Machine

@dataclass
class SubstitutionAlgebra: View Source

     7@dataclass
     8class SubstitutionAlgebra:
     9    """
    10    The algebraic structure of valid substitutions over a Machine,
    11    derived from a syntagmatic specification, and the machines internal constraints.
    12    """
    13    syntagmatics : Syntagmatics
    14    model        : Machine

The algebraic structure of valid substitutions over a Machine, derived from a syntagmatic specification, and the machines internal constraints.

SubstitutionAlgebra( syntagmatics: amachine.am_syntagmatics.Syntagmatics, model: amachine.am_machine.Machine)
syntagmatics: amachine.am_syntagmatics.Syntagmatics
model: amachine.am_machine.Machine